function   [results, parameters]= FDMa_analyze(X0, parameters)
% function [results, parameters]= FDMa_analyze(X0, parameters)
%
% FREQUENCY-DOMAIN MULTIVARIATE ANALYSIS (c) 2008 
% http://www.fdm.uni-freiburg.de
%
% Uses ARFIT.M from http://www.gps.caltech.edu/~tapio/arfit/ but the VAR

vars= genvarname(fieldnames(parameters));
for i= 1:length(vars)
   eval([vars{i} '= parameters.(vars{i});'])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Dimensions: N: length, D: number of signals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[N, D]= size(X0);
results.X0= X0;
results.N= N;
results.D= D;
results.win= win;
results.taperwin= taperwin;
parameters.X0= X0;
parameters.N= N;
parameters.D= D;
Nfreq= N/2;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Degrees of freedom with smoothing and tapering
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
nu= 2/sum(win.^2)*sum(taperwin.^2)^2/(sum(taperwin.^4))/N;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Tapering and mean subtraction of the data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
X= [];
for d= 1:D
   X(:, d)= X0(:, d)-mean(X0(:, d));
   X(:, d)= X(:, d).*taperwin;
   X(:, d)= X(:, d)-mean(X(:, d));
   X(:, d)= X(:, d)/sqrt(var(X(:, d)));
end
results.X= X;
parameters.X= X;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Spectral matrix estimate 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
results.SMP= zeros(D, D, N/2);
Xfft= fftshift(fft(X, [], 1), 1);
d1= 1;
for d1= 1:D
   d2= 1;
   for d2= 1:D
      WXd1d2= conv(win, Xfft(:, d1).*conj(Xfft(:, d2))/N);
      WXd1d2= WXd1d2((length(win)+1)/2:end-(length(win)-1)/2);
      results.SMP(d1, d2, :)= WXd1d2(N/2+1:end);
   end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% VAR estimation using the BIC
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   [meanval, Ahat, Chat, SBC, FPE, th]= arfit(X, Pmin, Pmax, 'sbc', 'zero');
   Phat= size(Ahat, 2)/size(Ahat, 1);
   results.Ahat= Ahat;
   results.Phat= Phat;
   results.Chat= Chat;
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Spectral polynomial
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   Apoly= reshape([eye(D) -results.Ahat ], D, D, Phat+1);
   Aspec= fftshift(fft(Apoly, N, 3), 3);
   Aspec= Aspec(:, :, N/2+1:end);
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Innovations covariance matrix
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   XX= [];
   p= 0;
   for p= 0:Phat
      XXX= [zeros(p, D); X(1:end-p, :)];
      XX= [XX XXX];      
   end
   EE= ([eye(D) -Ahat]*XX.').';
   results.Sigma= EE'*EE/N;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% VAR spectral matrix estimate
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   results.VAR= results.SMP;
   iomega= 1;
   for iomega= 1:Nfreq
      vvv= inv(Aspec(:, :, iomega))*Chat*inv(Aspec(:, :, iomega))';
      ddd= diag(diag(real(vvv)));
      vvv= vvv.*(1-eye(D))+ddd;
      results.VAR(:, :, iomega)= vvv-imag(diag(diag(vvv)));
   end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PD times PD Correlation matrix R
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   R= XX(:, D+1:end).' * XX(:, D+1:end)/N;
   [Vev, Dev]= eig(R);
   minev= min(diag(Dev));
   if(minev<0)
      Dev= Dev+abs(minev)*1.05*eye(D*results.Phat);
   end
   H= Vev * ( diag(1./diag(Dev)) ) * Vev';

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Partial coherence significance niveau
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   PCsig= sqrt(1-siglev^(2/(nu-2-2*(D-2))));
   results.COHsig= PCsig*ones(size(results.SMP));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Coherence significance niveau
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   COHsig= sqrt(1-siglev^(2/(nu-2)));
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Partial coherence into COH
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   results.COH= results.SMP;
   iomega= 1;
   for iomega= 1:Nfreq
      iSMP= pinv(results.SMP(:, :, iomega));
      gggg= diag(1./sqrt(diag(iSMP)));
      results.COH(:, :, iomega)= abs(gggg*iSMP*gggg);
   end%for iomega= 1:Nfreq

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Coherence and SMP onto main diagonal of COH
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   d1= 1;
   for d1= 1:D
      d2= 1;
      for d2= d1:D
         results.COHsig(d1, d2, :)= COHsig*ones(1, 1, Nfreq);
         if(d1==d2)
            results.COH(d1, d1, :)= results.SMP(d1, d1, :);
         else
            results.COH(d1, d2, :)= abs(results.SMP(d1, d2, :))./sqrt(results.SMP(d1, d1, :).*results.SMP(d2, d2, :));
         end
      end
   end
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PDC 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   PDCnorma= sum(Aspec.*conj(Aspec), 1);
   results.PDC= results.VAR;
   d1= 1;
   for d1= 1:D
      results.PDC(d1, :, :)= abs(Aspec(d1, :, :))./sqrt(PDCnorma(1, :, :));
      results.PDC(d1, d1, :)= results.VAR(d1, d1, :);
   end%for d1= 1:D
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Cd1d2 for PDC significance niveau
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   Cd1d2= results.VAR;
   interm= zeros(1, D, Nfreq);
   k= 1;
   for k= 1:results.Phat
      ck= cos(2*pi*((1:Nfreq)-1)/N * k);
      sk= sin(2*pi*((1:Nfreq)-1)/N * k);
      l= 1;
      for l= 1:results.Phat
         cl= cos(2*pi*((1:Nfreq)-1)/N * l);
         sl= sin(2*pi*((1:Nfreq)-1)/N * l);
         Hkl= H((k-1)*D+1:k*D, (l-1)*D+1:l*D);
         iii= zeros(1, D, Nfreq);
         d2= 1;
         for d2= 1:D
            iii(1, d2, :)= Hkl(d2, d2)*(ck.*cl + sk.*sl);
         end
         interm= interm + iii;
      end
   end
   d1= 1;
   for d1= 1:D
      d2= 1;
      for d2= 1:D
         Cd1d2(d1, d2, :)= interm(1, d2, :)*results.Sigma(d1, d1);
      end
   end%for d1= 1:D
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PDC significance niveau
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   chivalue= chi2inv(1-siglev, 1);
   results.PDCsig= results.VAR;
   d1= 1;
   for d1= 1:D
      results.PDCsig(d1, :, :)= sqrt(chivalue*Cd1d2(d1, :, :)./PDCnorma(1, :, :)/N);
   end%for d1= 1:D
   
results.string= sprintf('L%d, N%d, Fs%4.3f, P%d>%d<%d, h%d, sig%4.3f', Ldo, N, Fs, Pmin, results.Phat, Pmax, h, siglev);



if(0)
   save('~/R/FDMa_X.dat', '-ASCII', 'X')
   save('~/R/FDMa_P.dat', '-ASCII', 'Phat')
   pppath= pwd;
   cd('~/R')
   [ss, ww]= system('R --slave --file=confidencePDCfinal.r');
   cd(pppath)
   
   RPDC= load('~/R/FDMa_PDC.dat');
   RPDC= sqrt(reshape(RPDC, D, D, N/2));
%   RPDC= sqrt(reshape(RPDC, D, D, 62));
   
   RPDCsig= load('~/R/FDMa_PDCsig.dat');
   RPDCsig= sqrt(reshape(RPDCsig, D, D, N/2));
%   RPDCsig= sqrt(reshape(RPDCsig, D, D, 62));
   
   RAhat= load('~/R/FDMa_VAR.dat');
   RSigma= load('~/R/FDMa_Sigma.dat');
   RR= load('~/R/FDMa_R.dat');
   HH= load('~/R/FDMa_H.dat');
   
   RCd1d2= load('~/R/FDMa_Cd1d2.dat');
   RCd1d2= reshape(RCd1d2, D, D, N/2);
%   RCd1d2= reshape(RCd1d2, D, D, 62);
   disp('AHAT:')
   norm(Ahat(:)-RAhat(:))/norm(RAhat(:))
   figure(97);clf
   d1= 1;
   for d1= 1:D
      d2= 3;
      for d2= 1:D
         if(d1==d2)
         else
            subplot(D, D, (d1-1)*D+d2);cla;hold on
            plot(squeeze(Cd1d2(d1, d2, :)) , 'Color', 'b', 'LineStyle', '-', 'LineWidth', 2)
            plot(squeeze(RCd1d2(d1, d2, :)), 'Color', 'b', 'LineStyle', ':', 'LineWidth', 2)
            axis([1 N/2 0 15])
         end
      end
   end
   figure(98);clf
   d1= 1;
   for d1= 1:D
      d2= 3;
      for d2= 1:D
         if(d1==d2)
         else
            [d1 d2...
            norm(squeeze(results.PDC(d1, d2, :)-RPDC(d1, d2, :)))/norm(squeeze(RPDC(d1, d2, :)))...
            norm(squeeze(results.PDCsig(d1, d2, :)-RPDCsig(d1, d2, :)))/norm(squeeze(RPDCsig(d1, d2, :)))...
            norm(squeeze(Cd1d2(d1, d2, :)-RCd1d2(d1, d2, :)))/norm(squeeze(RCd1d2(d1, d2, :)))...
            ]
            subplot(D, D, (d1-1)*D+d2);cla;hold on
            plot(squeeze(results.PDC(d1, d2, :)), 'Color', 'k', 'LineStyle', '-', 'LineWidth', 2)
            plot(squeeze(RPDC(d1, d2, :))       , 'Color', 'k', 'LineStyle', ':', 'LineWidth', 2)
            axis([1 N/2 0 1])
         end
      end
   end
   figure(99);clf
   for d1= 1:D
      for d2= 1:D
         if(d1==d2)
         else
            subplot(D, D, (d1-1)*D+d2);cla;hold on
            plot(squeeze(results.PDCsig(d1, d2, :)), 'Color', 'r', 'LineStyle', '-', 'LineWidth', 2)
            plot(squeeze(RPDCsig(d1, d2, :))       , 'Color', 'r', 'LineStyle', ':', 'LineWidth', 2)
            axis([1 N/2 0 1])
         end
      end
   end
   drawnow
end
