%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% FREQUENCY-DOMAIN MULTIVARIATE ANALYSIS (c) 2008 
% http://www.fdm.uni-freiburg.de
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Create a list of all available examples
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
examples= {...
   'Figure2', ...
   'VAR[3]-0', ...
   'VAR[3]-2', ...
   'VAR[3]-3', ...
   'VanderPol',...
   'tremor_book', ...
};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Say hello
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp(sprintf('\n\n\nFREQUENCY-DOMAIN MULTIVARIATE ANALYSIS (c) 2008 http://www.fdm.uni-freiburg.de\n'))
disp(sprintf('   Checking for necessary third-party software ... \n'))
error= 0;
if(~exist('arfit.m', 'file'))
   disp('Please install the ARFIT TOOLBOX from http://www.gps.caltech.edu/~tapio/arfit/\n')
   error= 1;
end
%if(system('neato -V'))
%   disp(sprintf('\nPlease install the graphviz software from http://www.graphviz.org/\n'))
%   error= 1;
%end
if(error)
   disp(sprintf('FDMa_demo.m: aborted'))
   return
end
disp(sprintf('\n\n   all necessary third-party software available:)\n\n'))
disp(sprintf('possibly creating output-directory FDMa_output\n'))

%cd('~')

if(~exist('FDMa_output', 'dir'))
   mkdir('FDMa_output');
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% The menu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp(sprintf('which example from the book shall be run? Type 0 for all\n'))
for ex= 1:length(examples)
   disp(sprintf('%7d : %s', ex, examples{ex}))
end
disp(' ')
menustr= sprintf('enter a number between 0 and %d: ', length(examples));
ex= length(examples)+1;
while(ex<0 || ex>length(examples))
   ex= input(menustr);
end
if(ex)
   savefilenames= {examples{ex}};
else
   savefilenames= examples;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
for ff= 1:length(savefilenames)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   savefilename= savefilenames{ff};
   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Default settings for linmuti_analyze parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   clear parameters
   FDMa_defaultparameters

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Generate/load the data X
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
switch(savefilename)
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 'Figure2'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%------Generate X------------------------------------------------
N= 4096;
D= 3;
A0= [eye(D) [-.4 0 0; -.3 .5 0; .2 0 -.9] [.6 0 0 ; .1 -.4 0; -.4 0 .6]];
B0= eye(D);
p= size(A0(:, D+1:end), 2)/size(A0, 1);
q= size(B0(:, D+1:end), 2)/size(B0, 1);
D= size(A0, 1);

% Load the data file
X= load('Figure2.txt');

% Override order selection
parameters.P0= 2;
% Frequencies at which the graph will be computed
parameters.f0= [200];
parameters.node_positions= {'1.8182,2.2341!', '0.227273,1.25!', '1.8182,0.2659!'};
% Tick spacing
parameters.deltaT= 10;% sec
parameters.deltaF= 200;% Hz
% Max. plotting frequency
parameters.plotmaxfreq= 400;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case {...
       'VAR[3]-0', ...
   	 'VAR[3]-2', ...
   	 'VAR[3]-3', ...
	}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%------Generate X------------------------------------------------
N= 32768;
a1= [...
    0.8  0.0  0.4  0.0;...
    0.0  0.0  0.0  0.0;...
    0.0  0.6  0.0  0.0;...
    0.0  0.0  0.0  0.0;...
];
a2= [...
   -0.7  0.0  0.0  0.0;...
   -0.4  0.0  0.0  0.0;...
    0.0  0.0  0.0  0.0;...
    0.0  0.0  0.0  0.0;...
];
a3= [...
    0.0  0.0  0.0  0.0;...
    0.0 -0.5  0.0  0.0;...
    0.0  0.0  0.0  0.0;...
    0.0  0.0 -0.5  0.0;...
];
D= size(a1, 1);
A0= [a1 a2 a3];
B0= eye(D);
p= size(A0(:, D+1:end), 2)/size(A0, 1);
q= size(B0(:, D+1:end), 2)/size(B0, 1);

% Load the data file
X= load('VAR[3].txt');
xdel= str2num(savefilename(8));
X= X(:, setdiff(1:D, xdel));

%------Override parameters---------------------------------------
% Frequencies at which the graph will be computed
parameters.f0= [156];
% Override order selection
parameters.P0= 10;
% autmatic smoother design
parameters.h0Hz= 5;
% Amplitude range for plotting (dB)
parameters.dynrange= 40;
parameters.node_labels= {'X1', 'X2', 'X3', 'X4'};
parameters.node_positions= {'0.1,1.9!', '1.9,1.9!', '1.9,0.1!', '0.1,0.1!'};

switch(savefilename)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
         case 'VAR[3]-2'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
parameters.node_labels= {'X1', 'X3', 'X4'};
parameters.node_positions= {'0.1,1.9!', '1.9,0.1!', '0.1,0.1!'};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
         case 'VAR[3]-3'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
parameters.node_labels= {'X1', 'X2', 'X4'};
parameters.node_positions= {'0.1,1.9!', '1.9,1.9!', '0.1,0.1!'};
      end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    case 'VanderPol'
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%------Generate X------------------------------------------------
X= load('VanderPol.txt');
[N, D]= size(X);
%------Override parameters----------------------------------------
% Sampling frequency
parameters.Fs= 100;
% autmatic smoother design
parameters.h0Hz= .1;
% Override order selection
parameters.P0= 50;
% Amplitude range for plotting (dB)
parameters.dynrange= 60;% dB
% Tick spacing
parameters.deltaT= 10;% sec
parameters.deltaF= 2;% Hz
% Max. plotting frequency
parameters.plotmaxfreq= 20;
% Frequencies at which the graph will be computed
parameters.f0= [1.7];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   case 'tremor_book' 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%------Generate X------------------------------------------------
downs= 10;
X= load('tremor_data.txt');
[N, D]= size(X);

%------Override parameters----------------------------------------
% Sampling frequency
parameters.Fs= 1000;
% Override order selection, if 0 order estimation by the SIC
parameters.P0= 50;
% Subsampling factor
parameters.Ldo= downs;
% Tick spacing
parameters.deltaT= 10;% sec
parameters.deltaF= 10;% Hz
% Override smoother design. Give half smoother width in Hertz, if 0 autmatic smoother design
parameters.h0Hz= .5;
% Frequencies at which the graph will be computed, if empty no graph files are produced
parameters.f0= [4.7];
% Amplitude range for plotting (dB)
parameters.dynrange= 30;
parameters.node_positions= {'1.8182,2.2341!', '0.227273,1.25!', '1.8182,0.2659!'};
% Max. plotting frequency
parameters.plotmaxfreq= parameters.Fs/downs/2;

%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
end%switch(savefilename)
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% The call
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
close all
results= FDMa(X, parameters, savefilename);
cd('..')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end%for ff= 1:length(savefilenames)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
