function   FDMa_plot(parameters, savefilename)
% function FDMa_plot(parameters, savefilename)
%
% FREQUENCY-DOMAIN MULTIVARIATE ANALYSIS (c) 2008 
% http://www.fdm.uni-freiburg.de
%
% Plots the results from FDMa, with are written to the file
% "savefilename" into  MATLAB-Figures. 

warning off

vars= genvarname(fieldnames(parameters));
for i= 1:length(vars)
   eval([vars{i} '= parameters.(vars{i});'])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Load the results 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load(savefilename)
vars= genvarname(fieldnames(results));
for i= 1:length(vars)
   eval([vars{i} '= results.(vars{i});'])
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Amplitude ranges for spectral estimates 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
cross= [];
for d1= 1:D
   for d2= 1:D
      ccc= SMP(d1, d2, :);
      ddd= VAR(d1, d2, :);
      cross= [cross; ccc(:); ddd(:)];
   end
end

axes_psd= [1 freq2bin(plotmaxfreq, parameters)-1 1.1*10^(ceil(log10(max(abs(cross(:)))))-parameters.dynrange/10) 1.1*10^(ceil(log10(max(abs(cross(:))))))];
axes_coh= [1 freq2bin(plotmaxfreq, parameters)-1 -.1 1.1];
frequency_ticks= 1:deltaF*N/Fs:N;
frequency_labels= (frequency_ticks-1)/N*Fs;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot the signals
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
maxX= max(abs(X(:)))*1.1;
pos= 10;
figure_SIG= figure('Position', position_SIG, 'Name', 'Signal');clf;hold on
for d1= 1:D

%% The following can be activated to display some diagnostics:
%   if(d1==1)
%      title(sprintf('%s, %s', savefilename, results.string), 'Interpreter', 'none')
%   end
   plot(X(:, d1)-maxX*d1, 'k')
   text(1, -maxX*d1, node_labels{d1})
   axis([1 length(X) -maxX*(D+1) 0])
   set(gca, 'XTick', 1:deltaT*Fs:N)
   set(gca, 'XTicklabel', 0:deltaT:N)
   set(gca, 'yTick', -maxX*D:maxX:0)
   set(gca, 'YTicklabel', [])
   box on
   if(plot_grid);grid on;end
end%for d1= 1:D
text(3*length(X)/4, -maxX*(D+.75), 'time')
%if(plot_diagnosis)
%   plot(maxX*taperwin/1.1, 'r--')
%end
drawnow
plotfilename= sprintf('%s-SIG', savefilename);
print('-depsc2', strcat(plotfilename, '.eps'));
if(plot_fig)
   saveas(figure_SIG, plotfilename, 'fig');
end
if(plot_zoom)
   set(gcf, 'PaperType', 'A4');
   set(gcf, 'PaperOrientation', 'landscape');
   set(gcf, 'PaperUnits', 'centimeters'); 
   set(gcf, 'PaperPositionMode', 'manual');
   set(gcf, 'PaperPosition', [0.63 0.63 28.41 19.72 ]);
   plotfilename= sprintf('%s-SIGzoom', savefilename);
   print('-depsc2', strcat(plotfilename, '.eps'));
   if(strcmp(computer, 'MACI'))
      system(sprintf('/usr/texbin/epstopdf %s.eps', plotfilename));
   else
      system(sprintf('/usr/bin/epstopdf %s.eps 2>/dev/null', plotfilename));
   end
end%if(plot_zoom)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot spectral matrix estimate
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure_SMP= figure('Position', position_SMP, 'Name', 'Spectral estimate');clf
d1= 1;
for d1= 1:D
   d2= 1;
   for d2= 1:D
      subplot(D, D, (d1-1)*D+d2, 'align');
      cla;hold on
      plot(abs(squeeze(SMP(d1, d2, :))), 'Color', 'k', 'LineWidth', 2)
      set(gca, 'YScale', 'log')
%      if(plot_diagnosis && ~isempty(f0))
%            diraci= zeros(N/2, 1);
%         diraci(floor(freq2bin(f0, parameters)-(length(win)-1)/2))= 1;
%         winplot= conv(win, diraci);
%         plot(winplot*10*log10(max(abs(cross(:))))/max(win)+10*log10(min(abs(cross(:)))), 'r')
%      end
      axis(axes_psd)
      if(dynrange>60)
         set(gca, 'YTick', 10.^(-10:2:10))
      else
         set(gca, 'YTick', 10.^(-10:10))
      end
      set(gca, 'XTick', frequency_ticks)
      set(gca, 'XTickLabel', frequency_labels)
      if(plot_minimal_labels)
         if(d1<D || d2>1);set(gca, 'XTickLabel', []);end
         if(d1==D && d2==1);xlabel('freq');end
         if(d2~=1);set(gca, 'YTickLabel', []);end
      end
      if(plot_grid);grid on;end
      box on
      if(f0)
         line([freq2bin(f0(:), parameters)'; freq2bin(f0(:), parameters)'], (ones(size(f0(:)))*axes_psd(3:4))', 'Color', 'g', 'LineStyle', '--')
      end
      title(sprintf('SMP%d%d', d1, d2))
      ylabel(sprintf('ySMP%d%d', d1, d2))
   end%for d2= 1:D
end%for d1= 1:D
drawnow
plotfilename= sprintf('%s-SMP', savefilename);
print('-depsc2', strcat(plotfilename, '.eps'));
if(plot_fig)
   saveas(figure_SMP, plotfilename, 'fig');
end
if(plot_zoom)
   set(gcf, 'PaperType', 'A4');
   set(gcf, 'PaperOrientation', 'landscape');
   set(gcf, 'PaperUnits', 'centimeters'); 
   set(gcf, 'PaperPositionMode', 'manual');
   set(gcf, 'PaperPosition', [0.63 0.63 28.41 19.72 ]);
   plotfilename= sprintf('%s-SMPzoom', savefilename);
   print('-depsc2', strcat(plotfilename, '.eps'));
   if(strcmp(computer, 'MACI'))
      system(sprintf('/usr/texbin/epstopdf %s.eps', plotfilename));
   else
      system(sprintf('/usr/bin/epstopdf %s.eps 2>/dev/null', plotfilename));
   end
end%if(plot_zoom)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot VAR spectral matrix estimate
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure_VAR= figure('Position', position_VAR, 'Name', 'VAR Spectral estimate');clf
d1= 1;
for d1= 1:D
   d2= 1;
   for d2= 1:D
      subplot(D, D, (d1-1)*D+d2, 'align');
      cla;hold on
      plot(abs(squeeze(VAR(d1, d2, :))), 'Color', 'k', 'LineWidth', 2)
      set(gca, 'YScale', 'log')
      axis(axes_psd)
      if(dynrange>60)
         set(gca, 'YTick', 10.^(-10:2:10))
      else
         set(gca, 'YTick', 10.^(-10:10))
      end
      set(gca, 'XTick', frequency_ticks)
      set(gca, 'XTickLabel', frequency_labels)
      if(plot_minimal_labels)
         if(d1<D || d2>1);set(gca, 'XTickLabel', []);end
         if(d1==D && d2==1);xlabel('freq');end
         if(d2~=1);set(gca, 'YTickLabel', []);end
      end
      if(plot_grid);grid on;end
      box on
      if(f0)
         line([freq2bin(f0(:), parameters)'; freq2bin(f0(:), parameters)'], (ones(size(f0(:)))*axes_psd(3:4))', 'Color', 'g', 'LineStyle', '--')
      end
      title(sprintf('VAR%d%d', d1, d2))
      ylabel(sprintf('yVAR%d%d', d1, d2))
   end%for d2= 1:D
end%for d1= 1:D
drawnow
plotfilename= sprintf('%s-VAR', savefilename);
print('-depsc2', strcat(plotfilename, '.eps'));
if(plot_fig)
   saveas(figure_VAR, plotfilename, 'fig');
end
if(plot_zoom)
   set(gcf, 'PaperType', 'A4');
   set(gcf, 'PaperOrientation', 'landscape');
   set(gcf, 'PaperUnits', 'centimeters'); 
   set(gcf, 'PaperPositionMode', 'manual');
   set(gcf, 'PaperPosition', [0.63 0.63 28.41 19.72 ]);
   plotfilename= sprintf('%s-VARzoom', savefilename);
   print('-depsc2', strcat(plotfilename, '.eps'));
   if(strcmp(computer, 'MACI'))
      system(sprintf('/usr/texbin/epstopdf %s.eps', plotfilename));
   else
      system(sprintf('/usr/bin/epstopdf %s.eps 2>/dev/null', plotfilename));
   end
end%if(plot_zoom)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot COH 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure_COH= figure('Position', position_COH, 'Name', 'Coherence and PC');clf
FDMa_plotmatrix(COH, COHsig, 'PC', 'COH', 'SMP', axes_psd, axes_coh, frequency_ticks, frequency_labels, parameters);
plotfilename= sprintf('%s-COH', savefilename);
print('-depsc2', strcat(plotfilename, '.eps'));
if(plot_fig)
   saveas(figure_COH, plotfilename, 'fig');
end
if(plot_zoom)
   set(gcf, 'PaperType', 'A4');
   set(gcf, 'PaperOrientation', 'landscape');
   set(gcf, 'PaperUnits', 'centimeters'); 
   set(gcf, 'PaperPositionMode', 'manual');
   set(gcf, 'PaperPosition', [0.63 0.63 28.41 19.72 ]);
   plotfilename= sprintf('%s-COHzoom', savefilename);
   print('-depsc2', strcat(plotfilename, '.eps'));
   if(strcmp(computer, 'MACI'))
      system(sprintf('/usr/texbin/epstopdf %s.eps', plotfilename));
   else
      system(sprintf('/usr/bin/epstopdf %s.eps 2>/dev/null', plotfilename));
   end
end%if(plot_zoom)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Plot PDC 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure_PDC= figure('Position', position_PDC, 'Name', 'Partial directed coherence');clf
FDMa_plotmatrix(PDC, PDCsig, 'PDC', 'PDC', 'VAR', axes_psd, axes_coh, frequency_ticks, frequency_labels, parameters);
plotfilename= sprintf('%s-PDC', savefilename);
print('-depsc2', strcat(plotfilename, '.eps'));
if(plot_fig)
   saveas(figure_PDC, plotfilename, 'fig');
end
if(plot_zoom)
   set(gcf, 'PaperType', 'A4');
   set(gcf, 'PaperOrientation', 'landscape');
   set(gcf, 'PaperUnits', 'centimeters'); 
   set(gcf, 'PaperPositionMode', 'manual');
   set(gcf, 'PaperPosition', [0.63 0.63 28.41 19.72 ]);
   plotfilename= sprintf('%s-PDCzoom', savefilename);
   print('-depsc2', strcat(plotfilename, '.eps'));
   if(strcmp(computer, 'MACI'))
      system(sprintf('/usr/texbin/epstopdf %s.eps', plotfilename));
   else
      system(sprintf('/usr/bin/epstopdf %s.eps 2>/dev/null', plotfilename));
   end
end%if(plot_zoom)
warning on




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(FDMaversion==2)%% Plot npPDC 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure_npPDC= figure('Position', position_npPDC, 'Name', 'np Partial directed coherence');clf
FDMa_plotmatrix(npPDC, npPDCboot, 'npPDC', 'npPDC', 'SMP', axes_psd, axes_coh, frequency_ticks, frequency_labels, parameters);
plotfilename= sprintf('%s-npPDC', savefilename);
print('-depsc2', strcat(plotfilename, '.eps'));
if(plot_fig)
   saveas(figure_npPDC, plotfilename, 'fig');
end
if(plot_zoom)
   set(gcf, 'PaperType', 'A4');
   set(gcf, 'PaperOrientation', 'landscape');
   set(gcf, 'PaperUnits', 'centimeters'); 
   set(gcf, 'PaperPositionMode', 'manual');
   set(gcf, 'PaperPosition', [0.63 0.63 28.41 19.72 ]);
   plotfilename= sprintf('%s-npPDCzoom', savefilename);
   print('-depsc2', strcat(plotfilename, '.eps'));
   if(strcmp(computer, 'MACI'))
      system(sprintf('/usr/texbin/epstopdf %s.eps', plotfilename));
   else
      system(sprintf('/usr/bin/epstopdf %s.eps 2>/dev/null', plotfilename));
   end
end%if(plot_zoom)
warning on
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
end%if(FDMaversion==2)%% Plot npPDC 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function  FDMa_plotmatrix(PLOTMATRIX, PLOTMATRIXsig, PLOTMATRIXtitlelower, PLOTMATRIXtitleupper, PLOTMATRIXdiagtitle, axes_psd, axes_coh, frequency_ticks, frequency_labels, parameters)
% Plot a matrix: PLOTMATRIX and PLOTMATRIXsig, PLOTMATRIXtitle, PLOTMATRIXdiagtitle

vars= genvarname(fieldnames(parameters));
for i= 1:length(vars)
   eval([vars{i} '= parameters.(vars{i});'])
end
for d1= 1:D
   for d2= 1:D
      subplot(D, D, (d1-1)*D+d2, 'align');
      if(d1~=d2)
         cla;hold on
         plot(squeeze(PLOTMATRIX(d1, d2, :))    , 'Color', 'k', 'LineWidth', 2)
         plot(squeeze(PLOTMATRIXsig(d1, d2, :)) , 'Color', 'r', 'LineWidth', 1)
         axis(axes_coh)
         set(gca, 'XTick', frequency_ticks)
         set(gca, 'XTickLabel', frequency_labels)
         set(gca, 'YTick', 0:.5:1)
         set(gca, 'YTickLabel', {'0.0', '0.5', '1.0'})
         if(plot_minimal_labels)
            if(d1<D || d2>1);set(gca, 'XTickLabel', []);end
            if(d2~=1);set(gca, 'YTickLabel', []);end
            if(d1==D && d2==D)
               text(3*axes_psd(2)/4, 10*axes_psd(3), 'f')
            end
         end
         if(plot_grid), grid on;end
         box on
         if(~isempty(f0) && plot_f0)
            line([freq2bin(f0(:), parameters)'; freq2bin(f0(:), parameters)'], (ones(size(f0(:)))*axes_coh(3:4))', 'Color', 'g', 'LineStyle', '--')
            for b= 1:length(f0)
               if(PLOTMATRIX(d1, d2, freq2bin(f0(b), parameters))>PLOTMATRIXsig(d1, d2, freq2bin(f0(b), parameters)))
                  plot(freq2bin(f0(b), parameters), 1, '*g')
               end
            end
         end
      else%if(d1~=d2)
      if(plot_diag)
         cla;hold on
         plot(abs(squeeze(PLOTMATRIX(d1, d2, :))), 'Color', 'k', 'LineWidth', 2)
         set(gca, 'YScale', 'log')
         axis(axes_psd)
         if(dynrange>60)
            set(gca, 'YTick', 10.^(-10:2:10))
         else
            set(gca, 'YTick', 10.^(-10:10))
         end
         set(gca, 'XTick', frequency_ticks)
         set(gca, 'XTickLabel', frequency_labels)
         if(plot_minimal_labels)
            if(d1<D || d2>1);set(gca, 'XTickLabel', []);end
            if(d2~=1);set(gca, 'YTickLabel', []);end
         end
         if(plot_grid);grid on;end
         box on
         title(sprintf('%s%d%d', PLOTMATRIXdiagtitle, d1, d2))
      else
         axis off
         text(.5, .5, sprintf('D%d', d1))
      end
      end%if(d1~=d2)
      if(d1>d2)
         title(sprintf('%s%d%d', PLOTMATRIXtitlelower, d1, d2))
         ylabel(sprintf('y%s%d%d', PLOTMATRIXtitlelower, d1, d2))
      end
      if(d1<d2)
         title(sprintf('%s%d%d', PLOTMATRIXtitleupper, d1, d2))
         ylabel(sprintf('y%s%d%d', PLOTMATRIXtitleupper, d1, d2))
      end
      if(d1==d2)
         title(sprintf('%s%d%d', PLOTMATRIXdiagtitle, d1, d2))
         ylabel(sprintf('y%s%d%d', PLOTMATRIXdiagtitle, d1, d2))
      end
      if(d1==D && d2==1);xlabel('freq');end
   end%for d2= 1:D
end%for d1= 1:D
drawnow
